#include "COLORS.inc"
#include "FUNCTIONS.inc"

/////////////////////////////////////////////////////////
// TRUE = 1 FALSE = 0
#declare Qual = 0;
#declare useHF = 0;
#declare viewLand = 1; 
#declare viewFern = 0; // WARNING - MEMORY INTENSIVE
#declare viewLeat = 1; 
#declare viewMill = 1; 
#declare viewTail = 1; 
#declare viewFlow = 1; 
#declare viewGrass = 0; // WARNING - VERY SLOW TO PARSE
#declare viewPatio = 1;
#declare viewWheel = 1;
#declare viewSluice = 1; 
/////////////////////////////////////////////////////////

camera {
  location <150, 100, -30> // Final Location
  look_at <20, 32, 90>

//  location <-26, 150, -50>
//  look_at <-26, 20, 100>
//  location <20, 25, 70>  // for the patio
//  look_at <20, 0, 120>   // for the patio
//  location <10, 100, -40> 
//  look_at <10, 0, -20>

}


light_source {
  <10000, 9000, -5000>
  colour 1
	area_light <4000, 0, 0>, <0, 4000, 0>, 20, 20
#if (Qual)
	adaptive 3
#else
	adaptive 0
#end
	jitter
}

// TEMPORARY Sky Sphere
// Create an infinite sphere around scene and allow any pigment on it
sky_sphere {
  pigment {
    gradient y
    color_map { [0.0 color rgb <0.7,0.7,1.0>] [1.0 color blue 0.5] }
  }
}

// Textures
#declare seed1 = seed(12345);
#include "woodmaps.inc"
#include "woods.inc"
#include "textures.inc"

#if(viewLand)
	#include "land.inc"
#end

#if(viewFern)
	#debug "Parsing Ferns\n"
	#include "plants.inc"

#else
	#debug "NO FERNS\n"
#end
           
// Block Declarations
#include "block.inc"
             

// stone Leat
#if(viewLeat)
	#debug "Parsing Leat\n"
	#include "leat/l_wall_b.inc" // Leat Base (Water-level)
	#include "leat/l_wall_d.inc" // Downstream Leat Wall
	#include "leat/l_wall_s.inc" // Stream-Side Leat Wall
	#include "leat/l_wall_v.inc" // Valley-Side Leat Wall
	#include "leat/l_wood.inc"   // Wooden Leat
	#include "leat/decking.inc"  // Decking over Leat
#else
	#debug "NO LEAT\n"
#end

// The Millhouse
#if(viewMill)
	#debug "Parsing Millhouse\n"
	#include "building/m_wall_1.inc" // Downstream Millhouse Wall - 1st Floor
	#include "building/m_wall_d.inc" // Downstream Millhouse Wall - Grnd Floor
	#include "building/m_wall_s.inc" // Stream-Side Millhouse Wall
	#include "building/m_wall_u.inc" // Upstream Millhouse Wall
	#include "building/m_wall_v.inc" // Valley-Side Millhouse Wall
	#include "building/m_floor.inc"  // Millhouse Floor and Ceiling
	#include "building/m_fascia.inc" // Fascia underneath rood
	#include "building/m_window.inc" // Millhouse Windows
	#include "building/m_glass.inc"  // Window Glass
#else
	#debug "NO MILLHOUSE\n"
#end

// Wheel Tailrace
#if(viewTail)
	#debug "Parsing Tailrace\n"
	#include "tailrace/t_wall_b.inc" // Tailrace Base (Water-level)
	#include "tailrace/t_wall_d.inc" // Downstream Tailrace Wall
	#include "tailrace/t_wall_u.inc" // Upstream Tailrace Wall
	#include "tailrace/t_wall_v.inc" // Valley-Side Tailrace Wall
#else
	#debug "NO TAILRACE\n"
#end

// Overflow
#if(viewFlow)
	#debug "Parsing Overflow\n"
	#include "overflow/o_wood.inc"   // Wooden Overflow
	#include "overflow/o_wall_b.inc" // Overflow Base
	#include "overflow/o_wall_d.inc" // Overflow Downstream Wall
	#include "overflow/o_wall_u.inc" // Overflow Upstream Wall
	#include "overflow/o_wall_v.inc" // Overflow Valley Retaining Wall
#else
	#debug "NO OVERFLOW\n"
#end

// Grass Lawns
#if(viewGrass)
	#debug "Parsing Grass\n"
	#include "grasspatch.inc"
#else
	#debug "NO GRASS\n"
#end
#include "grass.inc"
#debug "\n"

#if(viewPatio)
	#debug "Parsing Patio and Bridge\n"
	// "Patio" Area below overflow
	#include "patio.inc" // Patio area between Tailrace and Overflow

	// Wooden Bridge over tailrace
	#include "tailrace/t_bridge.inc"

#else
	#debug "NO PATIO\n"
#end

#if(viewWheel)
	#debug "Parsing Wheel\n"

	#declare sd1 = seed(2002);
	// Axle Support Pier
	#include "piers.inc"

	// Axle and Bearings
	#include "wheel/axle.inc"

	// Declarations for the Water-Wheel
	#include "wheel/w_ribs.inc"
	#include "wheel/w_bow.inc"
	#include "wheel/w_rim.inc"
	#include "wheel/w_bolts.inc"
	// Water-Wheel
	#include "wheel/wheel.inc"

	// Paddles, Floats and Supports
	#include "wheel/paddles.inc"

#else
	#debug "NO WHEEL\n"
#end

#if(viewSluice)
	#debug "Parsing Sluice\n"

	// Contains the declaration for the "Cog" Prism
	#include "sluice/cog.inc"

	// Leat Sluice
	#include "sluice/sluice_1.inc"
	#include "sluice/rack_1.inc"

	// Overflow Sluice
	#include "sluice/sluice_2.inc"
	#include "sluice/rack_2.inc"

	// Sluice Brickwork
	#include "sluice/sluice_b.inc"

#else
	#debug "NO SLUICE\n"
#end
